@@ -18,8 +18,8 @@ class JobService:
             params['status'] = status
         return self.client.http_get("/api/job/most_recent", params=params)
 
-    def get_most_recent_job_per_view(self, workspace_id):
-        return self.client.http_get("/api/modeltraining/most_recent_jobs_per_view", params={'workspaceId': workspace_id})
+    def get_most_recent_job_per_model(self, workspace_id):
+        return self.client.http_get("/api/modeltraining/most_recent_jobs_per_model", params={'workspaceId': workspace_id})
 
     def start_training(self, workspace_id):
         return self.client.http_post("/api/modeltraining/train", params={'workspaceId': workspace_id})
