@@ -1,5 +1,5 @@
 from ..classes.workspace import Workspace
-from ..classes.view import View
+from ..classes.model import Model
 
 class WorkspaceService:
     def __init__(self, client):
@@ -10,6 +10,6 @@ class WorkspaceService:
         return Workspace(
             workspace['id'],
             workspace['workspaceName'],
-            [View(id, view) for (id, view) in workspace['views'].items()],
+            [Model(id, model) for (id, model) in workspace['models'].items()],
             self.client
         )
